@@ -2,6 +2,8 @@ from tabulate import tabulate
 import datetime
 import re
 import tutum
+from dateutil import tz
+import ago
 
 from tutumcli.exceptions import NonUniqueIdentifier, ObjectNotFound, BadParameter
 
@@ -10,33 +12,21 @@ def tabulate_result(data_list, headers):
     print tabulate(data_list, headers, stralign="left")
 
 
-def humanize_date_difference_from_now(target_datetime):
-    now = datetime.datetime.utcnow()
-    dt = target_datetime - datetime.datetime.utcnow()
-    offset = dt.seconds + (dt.days * 60*60*24)
-    delta_s = offset % 60
-    offset /= 60
-    delta_m = offset % 60
-    offset /= 60
-    delta_h = offset % 24
-    offset /= 24
-    delta_d = offset
+def _from_utc_string_to_utc_datetime(utc_datetime_string):
+    if not utc_datetime_string:
+        return None
+    utc_date_object = datetime.datetime.strptime(utc_datetime_string, "%a, %d %b %Y %H:%M:%S +0000")
 
-    if delta_d > 1:
-        if delta_d > 6:
-            date = now + datetime.timedelta(days=-delta_d, hours=-delta_h, minutes=-delta_m)
-            return date.strftime('%A, %Y %B %m, %H:%I')
-        else:
-            wday = now + datetime.timedelta(days=-delta_d)
-            return wday.strftime('%A')
-    if delta_d == 1:
-        return "Yesterday"
-    if delta_h > 0:
-        return "%dh%dm ago" % (delta_h, delta_m)
-    if delta_m > 0:
-        return "%dm%ds ago" % (delta_m, delta_s)
-    else:
-        return "%ds ago" % delta_s
+    return utc_date_object
+
+
+def get_humanize_local_datetime_from_utc_datetime_string(utc_datetime_string):
+    local_now = datetime.datetime.now(tz.tzlocal())
+    utc_target_datetime = _from_utc_string_to_utc_datetime(utc_datetime_string)
+    if utc_target_datetime:
+        local_target_datetime = _from_utc_string_to_utc_datetime(utc_datetime_string).replace(tzinfo=tz.gettz("UTC")).astimezone(tz=tz.tzlocal())
+        return ago.human(local_now - local_target_datetime, precision=1)
+    return ""
 
 
 def is_uuid4(identifier):
